@@ -133,9 +133,10 @@ sub run {
 
     my $src = $group->get_source_processable;
     if (defined($src)) {
-        $built_with_golang
-          = $src->info->relation('build-depends')
+        $built_with_golang = $src->info->relation('build-depends')
           ->implies('golang-go | golang-any');
+    } else {
+        $built_with_golang = $pkg =~ m/^golang-/;
     }
 
     foreach my $file (sort keys %{$info->objdump_info}) {
